Path

Struct Path 

pub struct Path(/* private fields */);
A borrowed file path.

Implementations

Source

impl Path

pub fn new<S: AsRef<[u8]> + ?Sized>(path: &S) -> &Self

Create a Path from possibly null-terminated bytes.

pub unsafe fn from_ptr<'a>(ptr: *const c_char) -> &'a Self

Create a Path from a raw pointer.

Safety
  • ptr must not be null.
  • ptr must be null terminated.
  • ptr must be valid for reads up to the null terminator.
  • ptr must not be mutated for the duration of 'a.
  • The null terminator must be within isize::MAX bytes from ptr.
pub fn from_bytes_until_null(path: &[u8]) -> Result<&Self, MissingNullByte>

Create a Path from null-terminated bytes.

Errors

path must contain at least one null byte.

pub fn from_bytes(path: &[u8]) -> &Self

Create a Path from possibly null-terminated bytes.

pub fn from_cstr(path: &CStr) -> &Self

Create a Path from a CStr.

pub const fn as_bytes(&self) -> &[u8]

Returns the path as &[u8].

pub fn is_abs(&self) -> bool

Reports whether the path is absolute.

pub fn join<P: AsRef<Self>>(&self, path: P) -> PathBuf

Creates an owned PathBuf with path joined to self.

pub fn to_path_buf(&self) -> PathBuf

Converts the Path into a PathBuf.

pub fn with_cstr<R>(&self, f: &dyn Fn(*const c_char) -> R) -> R

Invokes f with Path converted to a null-terminated C-style string.